///// Copyright (c) 2017 Razeware LLC
/// 
/// Permission is hereby granted, free of charge, to any person obtaining a copy
/// of this software and associated documentation files (the "Software"), to deal
/// in the Software without restriction, including without limitation the rights
/// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
/// copies of the Software, and to permit persons to whom the Software is
/// furnished to do so, subject to the following conditions:
/// 
/// The above copyright notice and this permission notice shall be included in
/// all copies or substantial portions of the Software.
/// 
/// Notwithstanding the foregoing, you may not use, copy, modify, merge, publish,
/// distribute, sublicense, create a derivative work, and/or sell copies of the
/// Software in any work that is designed, intended, or marketed for pedagogical or
/// instructional purposes related to programming, coding, application development,
/// or information technology.  Permission for such use, copying, modification,
/// merger, publication, distribution, sublicensing, creation of derivative works,
/// or sale is expressly withheld.
/// 
/// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
/// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
/// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
/// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
/// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
/// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
/// THE SOFTWARE.

import Cocoa
import Spots

class ViewController: NSViewController {
  @IBOutlet weak var rightView: NSView!
  @IBOutlet weak var leftView: NSView!
  
  override func viewDidLoad() {
    super.viewDidLoad()
    
    guard let jsonPath = Bundle.main.path(forResource: "dinopedia", ofType: "json") else {
      print("JSON Path Not Found")
      return
    }
    let jsonURL = URL(fileURLWithPath: jsonPath)
    do {
      let jsonData = try Data(contentsOf: jsonURL, options: .mappedIfSafe)
      let jsonResult = try JSONSerialization.jsonObject(with: jsonData, options: .mutableContainers) as! [String: Any]
      
      let controller = SpotsController(jsonResult)
      controller.delegate = self
      controller.title = "Dinopedia"
      
      addChildViewController(controller)
      leftView.addSubview(controller.view)
      controller.view.translatesAutoresizingMaskIntoConstraints = false
      NSLayoutConstraint.activate([
        controller.view.leadingAnchor.constraint(equalTo: leftView.leadingAnchor, constant: 0),
        controller.view.trailingAnchor.constraint(equalTo: leftView.trailingAnchor, constant: 0),
        controller.view.topAnchor.constraint(equalTo: leftView.topAnchor, constant: 0),
        controller.view.bottomAnchor.constraint(equalTo: leftView.bottomAnchor, constant: 0)
        ])
    } catch {
      print("Error Creating View from JSON")
    }
  }
}

extension ViewController: ComponentDelegate {
  func component(_ component: Component, itemSelected item: Item) {
    let itemMeta = item.meta
    
    let newModel = ComponentModel(kind: .list, items: [
      Item(title: "Scientific Name: \(itemMeta["ScientificName"] as! String)", kind: "Cell"),
      Item(title: "Speed: \(itemMeta["Speed"] as! String)", kind: "Cell"),
      Item(title: "Lived: \(itemMeta["Lived"] as! String)", kind: "Cell"),
      Item(title: "Weight: \(itemMeta["Weight"] as! String)", kind: "Cell"),
      Item(title: "Diet: \(itemMeta["Diet"] as! String)", kind: "Cell"),
      ])
    let newComponent = Component(model: newModel)
    
    if childViewControllers.count > 1 {
      childViewControllers.removeLast()
      rightView.subviews.removeAll()
    }
    
    let detailController = SpotsController()
    detailController.components = [newComponent]
    detailController.title = item.title
    
    addChildViewController(detailController)
    rightView.addSubview(detailController.view)
    detailController.view.translatesAutoresizingMaskIntoConstraints = false
    NSLayoutConstraint.activate([
      detailController.view.leadingAnchor.constraint(equalTo: rightView.leadingAnchor, constant: 0),
      detailController.view.trailingAnchor.constraint(equalTo: rightView.trailingAnchor, constant: 0),
      detailController.view.topAnchor.constraint(equalTo: rightView.topAnchor, constant: 0),
      detailController.view.bottomAnchor.constraint(equalTo: rightView.bottomAnchor, constant: 0)
      ])
  }
}



